@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Header: /Users/claude/fuzz/lib/Genezzo/RCS/Tablespace.pm,v 7.11 2006/08/01 07:32:42 claude Exp claude $
+# $Header: /Users/claude/fuzz/lib/Genezzo/RCS/Tablespace.pm,v 7.12 2006/10/19 08:45:01 claude Exp claude $
 #
 # copyright (c) 2003-2006 Jeffrey I Cohen, all rights reserved, worldwide
 #
@@ -29,7 +29,7 @@ BEGIN {
     # set the version for version checking
 #    $VERSION     = 1.00;
     # if using RCS/CVS, this may be preferred
-    $VERSION = do { my @r = (q$Revision: 7.11 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
+    $VERSION = do { my @r = (q$Revision: 7.12 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r }; # must be all one line, for MakeMaker
 
     @ISA         = qw(Exporter);
 #    @EXPORT      = qw(&func1 &func2 &func4 &func5);
@@ -324,7 +324,8 @@ sub TableHash ()
                      tso       => $self,
                      GZERR     => $self->{GZERR},
                      bufcache  => $ts->{bc},
-                     dbh_ctx   => $args{dbh_ctx}
+                     dbh_ctx   => $args{dbh_ctx},
+                     object_type => $args{object_type}
                      );
 
         if (defined($args{object_id}))
@@ -1009,8 +1010,10 @@ sub TSAddFile ()
     my $blocksize = $self->{blocksize} ;
 
 #    my ($filesizenum, $filesizesuffix) = ($args{filesize} =~ m/(^\d+)/
-    
+
     my $tsfile = 
+        File::Spec->file_name_is_absolute($args{filename}) ?
+        ($args{filename}) :
         File::Spec->rel2abs(
                             File::Spec->catfile(
                                                 $ts_prefix,
