@@ -1,6 +1,6 @@
-REM  $Header: /Users/claude/fuzz/lib/Genezzo/RCS/dict.sql,v 1.11 2006/11/17 09:02:29 claude Exp claude $
+REM  $Header: /Users/claude/fuzz/lib/Genezzo/RCS/dict.sql,v 1.13 2007/01/09 09:23:28 claude Exp claude $
 REM
-REM $Revision: 1.11 $
+REM $Revision: 1.13 $
 REM
 REM copyright (c) 2005, 2006 Jeffrey I Cohen, all rights reserved, worldwide
 REM
@@ -30,9 +30,12 @@ select HavokUse('Genezzo::Havok::Utils') from dual;
 REM reload the userfunctions to load the new utils functions
 select HavokUse('Genezzo::Havok::UserFunctions', 'reload') from dual;
 
+REM load the help system
+select HavokUse('Genezzo::Havok::SysHelp') from dual;
+
+REM load sql scalar functions and comparison functions
 select HavokUse('Genezzo::Havok::SQLScalar') from dual;
 select HavokUse('Genezzo::Havok::SQLCompare') from dual;
 
-
 REM always commit changes!!
 commit ;
